# Tutorials

:::{toctree}
:caption: Deployment
:maxdepth: 1
Qwen2.5-Omni.md
Qwen2.5-7B
Qwen3-Dense
Qwen-VL-Dense.md
Qwen3-30B-A3B.md
Qwen3-235B-A22B.md
Qwen3-VL-235B-A22B-Instruct.md
Qwen3-Coder-30B-A3B
Qwen3_embedding
Qwen3_reranker
Qwen3-8B-W4A8
Qwen3-32B-W4A4
Qwen3-Next
Qwen3-Omni-30B-A3B-Thinking.md
DeepSeek-V3.1.md
DeepSeek-V3.2.md
DeepSeek-R1.md
GLM4.x.md
Kimi-K2-Thinking
PaddleOCR-VL
pd_colocated_mooncake_multi_instance
pd_disaggregation_mooncake_single_node
pd_disaggregation_mooncake_multi_node
long_sequence_context_parallel_single_node
long_sequence_context_parallel_multi_node
ray
310p
:::
